@@ -9,7 +9,8 @@ use std::io::SeekFrom;
 use std::net::TcpListener;
 use std::time::Duration;
 
-use futures::channel::mpsc;
+use futures::Sink;
+use futures::sync::mpsc;
 
 use file_api::http_reader::HttpReader;
 use file_api::reader::Reader;
